@@ -1,16 +1,16 @@
 #' Render RMarkdown document in a fresh session
 #'
 #' @noRd
-render_rmarkdown <- function(pkg, input, output, ..., copy_images = TRUE, quiet = TRUE) {
+render_rmarkdown <- function(pkg, input, output, ..., seed = NULL, copy_images = TRUE, quiet = TRUE) {
 
   input_path <- path_abs(input, pkg$src_path)
   output_path <- path_abs(output, pkg$dst_path)
 
   if (!file_exists(input_path)) {
-    stop("Can't find ", src_path(input), call. = FALSE)
+    cli::cli_abort("Can't find {src_path(input).", call = caller_env())
   }
 
-  cat_line("Reading ", src_path(input))
+  cli::cli_inform("Reading {src_path(input)}")
   digest <- file_digest(output_path)
 
   args <- list(
@@ -20,13 +20,26 @@ render_rmarkdown <- function(pkg, input, output, ..., copy_images = TRUE, quiet
     intermediates_dir = tempdir(),
     encoding = "UTF-8",
     envir = globalenv(),
+    seed = seed,
     ...,
     quiet = quiet
   )
 
   path <- tryCatch(
     callr::r_safe(
-      function(...) rmarkdown::render(...),
+      function(seed, envir, ...) {
+        if (!is.null(seed)) {
+          # since envir is copied from the parent fn into callr::r_safe(),
+          # set.seed() sets the seed in the wrong global env and we have to
+          # manually copy it over
+          set.seed(seed)
+          envir$.Random.seed <- .GlobalEnv$.Random.seed
+          if (requireNamespace("htmlwidgets", quietly = TRUE)) {
+            htmlwidgets::setWidgetIdSeed(seed)
+          }
+        }
+        rmarkdown::render(envir = envir, ...)
+      },
       args = args,
       show = !quiet,
       env = c(
@@ -38,10 +51,13 @@ render_rmarkdown <- function(pkg, input, output, ..., copy_images = TRUE, quiet
       )
     ),
     error = function(cnd) {
-      rule("RMarkdown error")
-      cat(gsub("\r", "", cnd$stderr, fixed = TRUE))
-      rule()
-      abort("Failed to render RMarkdown", parent = cnd)
+      cli::cli_abort(
+        c(
+          "Failed to render RMarkdown document.",
+          x = gsub("\r", "", cnd$stderr, fixed = TRUE)
+        ),
+        parent = cnd
+      )
     }
   )
 
@@ -54,7 +70,7 @@ render_rmarkdown <- function(pkg, input, output, ..., copy_images = TRUE, quiet
     )
   }
   if (digest != file_digest(output_path)) {
-    cat_line("Writing ", dst_path(output))
+    writing_file(path_rel(output_path, pkg$dst_path), output)
   }
 
   # Copy over images needed by the document
