@@ -10,21 +10,30 @@ ext_topics <- function(match_strings) {
 
   tibble::tibble(
     name = match_strings,
+    file_in = NA_character_,
     file_out = ext_href,
-    title = sprintf("%s (from %s)", ext_title, pkg),
+    alias = list(character()), # used to find icons,
     funs = ext_funs,           # used list alternative names
-    alias = list(character()), # used to find icons
+    title = sprintf("%s (from %s)", ext_title, pkg),
+    rd = list(character()),
+    source = NA_character_,
+    keywords = list(character()), # used for has_keyword()
+    concepts = list(character()), # used for has_concept()
     internal = FALSE
   )
 }
 
-# Adatpted from roxygen2::get_rd_from_help
+# Adapted from roxygen2::get_rd_from_help
 get_rd_from_help <- function(package, alias) {
   check_installed(package, "as it's used in the reference index.")
 
   help <- utils::help((alias), (package))
   if (length(help) == 0) {
-    abort(sprintf("Could not find documentation for %s::%s", package, alias))
+    fun <- paste0(package, "::", alias)
+    cli::cli_abort(
+      "Could not find documentation for {.fn {fun}}.",
+      call = caller_env()
+    )
     return()
   }
 
