@@ -1,9 +1,11 @@
 #' A
 #' @export
+#' @keywords foo
 a <- function() {}
 
 #' B
 #' @export
+#' @concept graphics
 b <- function() {}
 
 #' C
@@ -19,3 +21,9 @@ c <- function() {}
 #' E
 #' @name e
 NULL
+
+#' F
+#' @keywords internal
+#' @examples
+#' testpackage:::f()
+f <- function() {runif(5L)}
