@@ -26,6 +26,7 @@ test_that("data_news works as expected for h1 & h2", {
 
 test_that("multi-page news are rendered", {
   skip_if_no_pandoc()
+  local_edition(3)
 
   pkg <- local_pkgdown_site(meta = "
     news:
@@ -45,8 +46,8 @@ test_that("multi-page news are rendered", {
     "* second thing"
   ))
 
-  expect_snapshot_output(data_news(pkg)[c("version", "page", "anchor")])
-  expect_output(build_news(pkg))
+  expect_snapshot(data_news(pkg)[c("version", "page", "anchor")])
+  expect_snapshot(build_news(pkg))
 
   # test that index links are correct
   lines <- read_lines(path(pkg$dst_path, "news", "index.html"))
@@ -230,3 +231,16 @@ test_that("clear error for bad hierarchy - h3", {
   expect_snapshot_error(data_news(temp_pkg))
 })
 
+test_that("news can contain footnotes", {
+  pkg <- local_pkgdown_site()
+  write_lines(path = file.path(pkg$src_path, "NEWS.md"), c(
+    "## testpackage 1.0.0.9000",
+    "",
+    "* bullet",
+    "",
+    "* inline footnote^[used to fail] ",
+    ""
+  ))
+
+  expect_snapshot(x <- data_news(pkg))
+})
